package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.UserLikeMusic;
import com.ruoyi.system.mapper.UserLikeMusicMapper;
import com.ruoyi.system.service.IUserLikeMusicService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class UserLikeMusicServiceImpl implements IUserLikeMusicService 
{
    @Autowired
    private UserLikeMusicMapper userLikeMusicMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public UserLikeMusic selectUserLikeMusicById(String id)
    {
        return userLikeMusicMapper.selectUserLikeMusicById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param userLikeMusic 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<UserLikeMusic> selectUserLikeMusicList(UserLikeMusic userLikeMusic)
    {
        return userLikeMusicMapper.selectUserLikeMusicList(userLikeMusic);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param userLikeMusic 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertUserLikeMusic(UserLikeMusic userLikeMusic)
    {
        return userLikeMusicMapper.insertUserLikeMusic(userLikeMusic);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param userLikeMusic 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateUserLikeMusic(UserLikeMusic userLikeMusic)
    {
        return userLikeMusicMapper.updateUserLikeMusic(userLikeMusic);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteUserLikeMusicByIds(String[] ids)
    {
        return userLikeMusicMapper.deleteUserLikeMusicByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteUserLikeMusicById(String id)
    {
        return userLikeMusicMapper.deleteUserLikeMusicById(id);
    }
}
